@@ -3,8 +3,8 @@
   FILE: icaltime.c
   CREATOR: eric 02 June 2000
   
-  $Id: icaltime.c,v 1.42 2006/03/28 13:51:47 pchen Exp $
-  $Locker:  $
+  $Id: icaltime.c 554 2006-03-28 13:51:47Z pchen $
+  $Locker$
     
  (C) COPYRIGHT 2000, Eric Busboom, http://www.softwarestudio.org
 
