@@ -8,17 +8,17 @@
  * Copyright 2000-2003 Ximian, Inc. (www.ximian.com)
  *
  * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU General Public 
+ * modify it under the terms of version 2 of the GNU Lesser General Public 
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
@@ -27,10 +27,10 @@
 #include <config.h>
 #endif
 
+#include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <errno.h>
 
 /*
   if you want to build the charset map, compile this with something like:
@@ -106,6 +106,8 @@ int main (void)
 
 	for (j = 0; tables[j].name; j++) {
 		cd = iconv_open (UCS, tables[j].name);
+		if (cd == (iconv_t)-1)
+			exit (1);
 		inptr = in;
 		outptr = (char *)(out);
 		inlen = sizeof (in);
@@ -141,7 +143,7 @@ int main (void)
 			}
 			if (j < 256) {
 				/* yes, dump it */
-				printf("static unsigned char m%02x%x[256] = {\n\t", i, k);
+				printf("static const unsigned char m%02x%x[256] = {\n\t", i, k);
 				for (j=0;j<256;j++) {
 					printf("0x%02x, ", (encoding_map[i*256+j] >> (k*8)) & 0xff );
 					if (((j+1)&7) == 0 && j<255)
@@ -152,9 +154,9 @@ int main (void)
 		}
 	}
 
-	printf("struct {\n");
+	printf("static const struct {\n");
 	for (k=0;k<bytes;k++) {
-		printf("\tunsigned char *bits%d;\n", k);
+		printf("\tconst unsigned char *bits%d;\n", k);
 	}
 	printf("} camel_charmap[256] = {\n\t");
 	for (i=0;i<256;i++) {
@@ -168,7 +170,7 @@ int main (void)
 			if (j < 256) {
 				printf("m%02x%x, ", i, k);
 			} else {
-				printf("0, ");
+				printf("NULL, ");
 			}
 		}
 		printf("}, ");
@@ -177,7 +179,7 @@ int main (void)
 	}
 	printf("\n};\n\n");
 
-	printf("struct {\n\tconst char *name;\n\tunsigned int bit;\n} camel_charinfo[] = {\n");
+	printf("static const struct {\n\tconst char *name;\n\tunsigned int bit;\n} camel_charinfo[] = {\n");
 	for (j=0;tables[j].name;j++) {
 		printf("\t{ \"%s\", 0x%04x },\n", tables[j].name, tables[j].bit);
 	}
@@ -222,19 +224,20 @@ camel_charset_init (CamelCharset *c)
 void
 camel_charset_step (CamelCharset *cc, const char *in, int len)
 {
+	const unsigned char *inptr = (const unsigned char *) in;
+	const unsigned char *inend = inptr + len;
 	register unsigned int mask;
 	register int level;
-	const unsigned char *inptr = in, *inend = in+len;
 	register guint32 c;
-
+	
 	mask = cc->mask;
 	level = cc->level;
-
+	
 	/* check what charset a given string will fit in */
-	while ( (c = camel_utf8_getc_limit(&inptr, inend)) != 0xffff) {
+	while ((c = camel_utf8_getc_limit(&inptr, inend)) != 0xffff) {
 		if (c < 0xffff) {
 			mask &= charset_mask(c);
-		
+			
 			if (c>=128 && c<256)
 				level = MAX(level, 1);
 			else if (c>=256)
@@ -245,7 +248,7 @@ camel_charset_step (CamelCharset *cc, const char *in, int len)
 			break;
 		}
 	}
-
+	
 	cc->mask = mask;
 	cc->level = level;
 }
@@ -262,7 +265,7 @@ camel_charset_best_mask(unsigned int mask)
 		if (camel_charinfo[i].bit & mask) {
 			lang = e_iconv_charset_language (camel_charinfo[i].name);
 			
-			if (!lang || (locale_lang && !strncmp (locale_lang, lang, 2)))
+			if (!locale_lang || (lang && !strncmp (locale_lang, lang, 2)))
 				return camel_charinfo[i].name;
 		}
 	}
