@@ -16,7 +16,7 @@
  *
  *  You should have received a copy of the GNU Lesser General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  */
 
@@ -25,8 +25,10 @@
 #include <config.h>
 #endif
 
+#include <glib.h>
+#include <glib/gi18n-lib.h>
+
 #include "camel-folder.h"
-#include "camel-i18n.h"
 #include "camel-offline-folder.h"
 #include "camel-offline-store.h"
 #include "camel-session.h"
