@@ -19,7 +19,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
@@ -44,7 +44,7 @@
 #include "camel-stream-filter.h"
 #include "camel-stream-mem.h"
 
-#define d(x) 
+#define d(x)
 
 #define CF_CLASS(o) (CAMEL_FOLDER_CLASS (CAMEL_OBJECT_GET_CLASS(o)))
 static CamelFolderClass *parent_class;
@@ -164,8 +164,8 @@ cmd_builduid(CamelPOP3Engine *pe, CamelPOP3Stream *stream, void *data)
 		while (h) {
 			if (g_ascii_strcasecmp(h->name, "status") != 0
 			    && g_ascii_strcasecmp(h->name, "x-status") != 0) {
-				md5_update(&md5, h->name, strlen(h->name));
-				md5_update(&md5, h->value, strlen(h->value));
+				md5_update(&md5, (const guchar *) h->name, strlen(h->name));
+				md5_update(&md5, (const guchar *) h->value, strlen(h->value));
 			}
 			h = h->next;
 		}
@@ -174,7 +174,7 @@ cmd_builduid(CamelPOP3Engine *pe, CamelPOP3Stream *stream, void *data)
 	}
 	camel_object_unref(mp);
 	md5_final(&md5, digest);
-	fi->uid = camel_base64_encode_simple(digest, 16);
+	fi->uid = camel_base64_encode_simple((const char *) digest, 16);
 
 	d(printf("building uid for id '%d' = '%s'\n", fi->id, fi->uid));
 }
@@ -192,7 +192,7 @@ cmd_list(CamelPOP3Engine *pe, CamelPOP3Stream *stream, void *data)
 	do {
 		ret = camel_pop3_stream_line(stream, &line, &len);
 		if (ret>=0) {
-			if (sscanf(line, "%u %u", &id, &size) == 2) {
+			if (sscanf((char *) line, "%u %u", &id, &size) == 2) {
 				fi = g_malloc0(sizeof(*fi));
 				fi->size = size;
 				fi->id = id;
@@ -220,9 +220,9 @@ cmd_uidl(CamelPOP3Engine *pe, CamelPOP3Stream *stream, void *data)
 	do {
 		ret = camel_pop3_stream_line(stream, &line, &len);
 		if (ret>=0) {
-			if (strlen(line) > 1024)
+			if (strlen((char *) line) > 1024)
 				line[1024] = 0;
-			if (sscanf(line, "%u %s", &id, uid) == 2) {
+			if (sscanf((char *) line, "%u %s", &id, uid) == 2) {
 				fi = g_hash_table_lookup(folder->uids_id, GINT_TO_POINTER(id));
 				if (fi) {
 					camel_operation_progress(NULL, (fi->index+1) * 100 / folder->uids->len);
@@ -305,6 +305,8 @@ pop3_sync (CamelFolder *folder, gboolean expunge, CamelException *ex)
 
 	if(pop3_store->delete_after && !expunge)
 	{	
+		d(printf("%s(%d): pop3_store->delete_after = [%d], expunge=[%d]\n",
+			 __FILE__, __LINE__, pop3_store->delete_after, expunge));
 		camel_operation_start(NULL, _("Expunging old messages"));
 		camel_pop3_delete_old(folder, pop3_store->delete_after,ex);	
 	}	
@@ -364,20 +366,27 @@ camel_pop3_delete_old(CamelFolder *folder, int days_to_delete,	CamelException *e
 	int i;
 	CamelPOP3Store *pop3_store;
 	time_t temp;
-	CamelMimeMessage *message;
+	CamelMessageInfo *minfo;
 
 	pop3_folder = CAMEL_POP3_FOLDER (folder);
 	pop3_store = CAMEL_POP3_STORE (CAMEL_FOLDER(pop3_folder)->parent_store);	
 	temp = time(&temp);
 
+	d(printf("%s(%d): pop3_folder->uids->len=[%d]\n", __FILE__, __LINE__, pop3_folder->uids->len));
 	for (i = 0; i < pop3_folder->uids->len; i++) {
 		fi = pop3_folder->uids->pdata[i];
-	
-		message = pop3_get_message (folder, fi->uid, ex);
-		if(message) {
-			time_t message_time = message->date + message->date_offset;
+
+		minfo = camel_folder_get_message_info (folder, fi->uid);
+		d(printf("%s(%d): fi->uid=[%s]\n", __FILE__, __LINE__, fi->uid));
+		if(minfo) {
+			time_t message_time = ((CamelMessageInfoBase *)minfo)->date_received;
 			double time_diff = difftime(temp,message_time);
 			int day_lag = time_diff/(60*60*24);
+
+			d(printf("%s(%d): message_time= [%ld]\n", __FILE__, __LINE__, message_time));
+			d(printf("%s(%d): day_lag=[%d] \t days_to_delete=[%d]\n", 
+				 __FILE__, __LINE__, day_lag, days_to_delete));
+
 			if( day_lag > days_to_delete)
 			{
 				if (fi->cmd) {
@@ -388,7 +397,7 @@ camel_pop3_delete_old(CamelFolder *folder, int days_to_delete,	CamelException *e
 					camel_pop3_engine_command_free(pop3_store->engine, fi->cmd);
 					fi->cmd = NULL;
 				}
-		
+				d(printf("%s(%d): Deleting old messages\n", __FILE__, __LINE__));
 				fi->cmd = camel_pop3_engine_command_new(pop3_store->engine, 
 									0,
 									NULL,
@@ -401,7 +410,7 @@ camel_pop3_delete_old(CamelFolder *folder, int days_to_delete,	CamelException *e
 				}
 			}
 			/* free message - not used anymore */
-			camel_object_unref((CamelObject *)message);
+			camel_folder_free_message_info (folder, minfo);
 		}
 	}
 
