@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifndef __E_ACCOUNT__
@@ -101,6 +101,7 @@ typedef struct _EAccountService {
 	gboolean auto_check;
 	int auto_check_time;
 	gboolean save_passwd;
+	gboolean get_password_canceled;
 } EAccountService;
 
 typedef struct _EAccount {
