@@ -17,7 +17,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
@@ -44,7 +44,7 @@ struct _EGwContainerPrivate {
 	gboolean is_frequent_contacts; /*indicates  whether this folder is frequent contacts or not */
 	gboolean is_shared_by_me;   
 	gboolean is_shared_to_me;
-
+	gboolean is_system_folder;
 };
 
 static GObjectClass *parent_class = NULL;
@@ -62,6 +62,7 @@ free_node(EShUsers *user)
 		g_free(user->email);
 		user->email = NULL;
 	}
+	g_free (user);
 	return ;
 }
 
@@ -261,6 +262,15 @@ e_gw_container_set_from_soap_parameter (EGwContainer *container, SoupSoapParamet
 		g_free (value) ;
 	}
 
+	subparam = soup_soap_parameter_get_first_child_by_name (param, "isSystemFolder");
+	if (subparam) {
+		value = soup_soap_parameter_get_string_value (subparam);
+		if (!strcmp (value, "1"))
+			container->priv->is_system_folder = TRUE;
+		g_free (value);
+	}
+
+
 	/* retrive the unread and total count */
 	subparam = soup_soap_parameter_get_first_child_by_name (param, "hasUnread") ;
 	if (!subparam) {
@@ -283,9 +293,7 @@ e_gw_container_set_from_soap_parameter (EGwContainer *container, SoupSoapParamet
 		value = soup_soap_parameter_get_string_value (subparam) ;
 		if (value)
 			container->priv->total = atoi(value) ;
-		else
-			/*XXX:Some problem - should return FALSE??*/
-			g_free (value) ;
+		g_free (value) ;
 	}
 	/* Is shared by me*/
 	subparam = soup_soap_parameter_get_first_child_by_name (param, "isSharedByMe");
@@ -341,8 +349,7 @@ e_gw_container_set_from_soap_parameter (EGwContainer *container, SoupSoapParamet
 				} else {
 					value = soup_soap_parameter_get_string_value (email_rt_subparam);
 					if (value) {
-						user->email = g_strdup (value);
-						g_free (value);	
+						user->email = value;
 					}	
 					/* Retrieve Rights*/
 					email_rt_subparam = soup_soap_parameter_get_first_child_by_name (entry_subparam, "rights");
@@ -525,6 +532,22 @@ e_gw_container_set_is_shared_to_me (EGwContainer *container, gboolean is_shared_
 	container->priv->is_shared_to_me = is_shared_to_me;
 }
 
+gboolean
+e_gw_container_get_is_system_folder (EGwContainer *container)
+{
+	g_return_val_if_fail (E_IS_GW_CONTAINER (container), FALSE);
+	
+	return container->priv->is_system_folder;
+}
+
+void
+e_gw_container_set_is_system_folder (EGwContainer *container, gboolean is_system_folder)
+{
+	g_return_if_fail (E_IS_GW_CONTAINER (container));
+	
+	container->priv->is_system_folder = is_system_folder;
+}
+
 const char *
 e_gw_container_get_name (EGwContainer *container)
 {
